==> huaweicloudsdklts-3.1.96-py2.py3-none-any.whl: huaweicloudsdklts/v2/model/show_member_group_and_stream_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowMemberGroupAndStreamRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'member_account_id': 'str'
    }

    attribute_map = {
        'member_account_id': 'member_account_id'
    }

    def __init__(self, member_account_id=None):
        """ShowMemberGroupAndStreamRequest

        The model defined in huaweicloud sdk

        :param member_account_id: 成员账号ID
        :type member_account_id: str
        """
        
        

        self._member_account_id = None
        self.discriminator = None

        self.member_account_id = member_account_id

    @property
    def member_account_id(self):
        """Gets the member_account_id of this ShowMemberGroupAndStreamRequest.

        成员账号ID

        :return: The member_account_id of this ShowMemberGroupAndStreamRequest.
        :rtype: str
        """
        return self._member_account_id

    @member_account_id.setter
    def member_account_id(self, member_account_id):
        """Sets the member_account_id of this ShowMemberGroupAndStreamRequest.

        成员账号ID

        :param member_account_id: The member_account_id of this ShowMemberGroupAndStreamRequest.
        :type member_account_id: str
        """
        self._member_account_id = member_account_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowMemberGroupAndStreamRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdklts-3.1.158-py2.py3-none-any.whl: huaweicloudsdklts/v2/model/show_member_group_and_stream_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowMemberGroupAndStreamRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'member_account_id': 'str'
    }

    attribute_map = {
        'member_account_id': 'member_account_id'
    }

    def __init__(self, member_account_id=None):
        r"""ShowMemberGroupAndStreamRequest

        The model defined in huaweicloud sdk

        :param member_account_id: 成员账号ID
        :type member_account_id: str
        """
        
        

        self._member_account_id = None
        self.discriminator = None

        self.member_account_id = member_account_id

    @property
    def member_account_id(self):
        r"""Gets the member_account_id of this ShowMemberGroupAndStreamRequest.

        成员账号ID

        :return: The member_account_id of this ShowMemberGroupAndStreamRequest.
        :rtype: str
        """
        return self._member_account_id

    @member_account_id.setter
    def member_account_id(self, member_account_id):
        r"""Sets the member_account_id of this ShowMemberGroupAndStreamRequest.

        成员账号ID

        :param member_account_id: The member_account_id of this ShowMemberGroupAndStreamRequest.
        :type member_account_id: str
        """
        self._member_account_id = member_account_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowMemberGroupAndStreamRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
